# Sony Bravia PSK Python Package

[![Pypi](https://badge.fury.io/py/pySonyBraviaPSK.svg)](https://pypi.org/project/pysonybraviapsk)
[![Downloads](https://pepy.tech/badge/pysonybraviapsk/week)](https://pepy.tech/project/pysonybraviapsk/week)
[![Downloads](https://pepy.tech/badge/pysonybraviapsk/month)](https://pepy.tech/project/pysonybraviapsk/month)
[![Downloads](https://pepy.tech/badge/pysonybraviapsk)](https://pepy.tech/project/pysonybraviapsk)

## About

``sony_bravia_psk`` is a Python library for remote communication with Sony Bravia TVs 2014 and newer which support a Pre-Shared Key
(http://info.tvsideview.sony.net/en_ww/home_device.html#bravia)

## Thank you
The source of this is the great work of Antonio Parraga on https://github.com/aparraga/braviarc. That version is being used to
add the PSK functionality.

## Home Assistant
This version is being developed for use in Home Assistant.
